@@ -1076,7 +1076,6 @@ g_tls_connection_tls_source_dtls_closure_callback (GDatagramBased *datagram_base
   g_value_unset (&param[1]);
 
   return result;
-
 }
 
 static GSourceFuncs tls_source_funcs =
@@ -1138,7 +1137,7 @@ g_tls_connection_base_create_source (GTlsConnectionBase  *tls,
   if (cancellable)
     {
       cancellable_source = g_cancellable_source_new (cancellable);
-      g_source_set_dummy_callback (cancellable_source);
+      g_source_set_callback (cancellable_source, dummy_callback, NULL, NULL);
       g_source_add_child_source (source, cancellable_source);
       g_source_unref (cancellable_source);
     }
@@ -1228,7 +1227,6 @@ static GTlsCertificateFlags
 verify_peer_certificate (GTlsConnectionBase *tls,
                          GTlsCertificate    *peer_certificate)
 {
-  GTlsConnectionBaseClass *tls_class = G_TLS_CONNECTION_BASE_GET_CLASS (tls);
   GSocketConnectable *peer_identity;
   GTlsDatabase *database;
   GTlsCertificateFlags errors;
@@ -1271,9 +1269,6 @@ verify_peer_certificate (GTlsConnectionBase *tls,
         }
     }
 
-  if (tls_class->verify_peer_certificate)
-    errors |= tls_class->verify_peer_certificate (tls, peer_certificate, errors);
-
   return errors;
 }
 
@@ -1297,7 +1292,8 @@ update_peer_certificate_and_compute_errors (GTlsConnectionBase *tls)
   if (peer_certificate)
     peer_certificate_errors = verify_peer_certificate (tls, peer_certificate);
 
-  g_set_object (&priv->peer_certificate, peer_certificate);
+  g_clear_object (&priv->peer_certificate);
+  priv->peer_certificate = g_steal_pointer (&peer_certificate);
   g_clear_object (&peer_certificate);
 
   priv->peer_certificate_errors = peer_certificate_errors;
@@ -1858,8 +1854,8 @@ do_implicit_handshake (GTlsConnectionBase  *tls,
 
   g_assert (!priv->implicit_handshake);
   priv->implicit_handshake = g_task_new (tls, cancellable,
-                                        timeout ? sync_handshake_thread_completed : NULL,
-                                        NULL);
+                                         timeout ? sync_handshake_thread_completed : NULL,
+                                         NULL);
   g_task_set_source_tag (priv->implicit_handshake, do_implicit_handshake);
   g_task_set_name (priv->implicit_handshake, "[glib-networking] do_implicit_handshake");
 
